==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebDimensionsChangeDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotDimensionDescriptionMetadata } from "./WebPivotDimensionDescriptionMetadata";
import { WebDimensionsChangeDetailDescription } from "./WebDimensionsChangeDetailDescription";
/**
 * @hidden
 */
var WebDimensionsChangeDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebDimensionsChangeDetailDescriptionMetadata, _super);
    function WebDimensionsChangeDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDimensionsChangeDetailDescriptionMetadata.b = function (a) {
        if (WebDimensionsChangeDetailDescriptionMetadata.a == null) {
            WebDimensionsChangeDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDimensionsChangeDetailDescriptionMetadata.c(WebDimensionsChangeDetailDescriptionMetadata.a);
        }
        if (a.k(WebDimensionsChangeDetailDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebDimensionsChangeDetailDescriptionMetadata.a);
        WebPivotDimensionDescriptionMetadata.d(a);
    };
    WebDimensionsChangeDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DimensionsChangeDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Dimensions", "Array:WebPivotDimensionDescription:PivotDimension");
        a.item("DimensionCollectionType", "ExportedType:string:PivotDimensionType");
        a.item("DimensionCollectionType@names", "Row;Column;Filter");
    };
    WebDimensionsChangeDetailDescriptionMetadata.d = function (a) {
        WebDimensionsChangeDetailDescriptionMetadata.b(a);
        a.ac("WebDimensionsChangeDetail", function () { return new WebDimensionsChangeDetailDescription(); });
        a.ab("WebDimensionsChangeDetail", WebDimensionsChangeDetailDescriptionMetadata.a);
    };
    WebDimensionsChangeDetailDescriptionMetadata.$t = markType(WebDimensionsChangeDetailDescriptionMetadata, 'WebDimensionsChangeDetailDescriptionMetadata');
    WebDimensionsChangeDetailDescriptionMetadata.a = null;
    return WebDimensionsChangeDetailDescriptionMetadata;
}(Base));
export { WebDimensionsChangeDetailDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebDimensionsChangeDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotDimensionDescriptionMetadata } from "./WebPivotDimensionDescriptionMetadata";
import { WebDimensionsChangeDetailDescription } from "./WebDimensionsChangeDetailDescription";
/**
 * @hidden
 */
var WebDimensionsChangeDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebDimensionsChangeDetailDescriptionMetadata, _super);
    function WebDimensionsChangeDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDimensionsChangeDetailDescriptionMetadata.b = function (a) {
        if (WebDimensionsChangeDetailDescriptionMetadata.a == null) {
            WebDimensionsChangeDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDimensionsChangeDetailDescriptionMetadata.c(WebDimensionsChangeDetailDescriptionMetadata.a);
        }
        if (a.k(WebDimensionsChangeDetailDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebDimensionsChangeDetailDescriptionMetadata.a);
        WebPivotDimensionDescriptionMetadata.d(a);
    };
    WebDimensionsChangeDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:DimensionsChangeDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__marshalByValue", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Dimensions", "Array:WebPivotDimensionDescription:PivotDimension");
        a.item("DimensionCollectionType", "ExportedType:string:PivotDimensionType");
        a.item("DimensionCollectionType@names", "Row;Column;Filter");
    };
    WebDimensionsChangeDetailDescriptionMetadata.d = function (a) {
        WebDimensionsChangeDetailDescriptionMetadata.b(a);
        a.ae("WebDimensionsChangeDetail", function () { return new WebDimensionsChangeDetailDescription(); });
        a.ad("WebDimensionsChangeDetail", WebDimensionsChangeDetailDescriptionMetadata.a);
    };
    WebDimensionsChangeDetailDescriptionMetadata.$t = markType(WebDimensionsChangeDetailDescriptionMetadata, 'WebDimensionsChangeDetailDescriptionMetadata');
    WebDimensionsChangeDetailDescriptionMetadata.a = null;
    return WebDimensionsChangeDetailDescriptionMetadata;
}(Base));
export { WebDimensionsChangeDetailDescriptionMetadata };
